# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.__init__

Package containing the various security checker modules.

### Global Attributes

None

### Classes

None

### Functions

generateCheckersDict | Function to generate the dictionary with checkers.

## generateCheckersDict

generateCheckersDict()

Function to generate the dictionary with checkers.

Checker modules are searched for inside this package. Each module defining some checks must contain a function 'getChecks()' returning a dictionary containing the check type as key and a list of tuples with the check function and associated message codes.

Return:
  dictionary containing list of tuples with checker data

Return Type:
  dict

Up